==> Smdn.Net.Imap4.Client-0.34.tar.bz2: Smdn.Net.Imap4.Client-0.34/Smdn.Net.Imap4.Client/Smdn.Net.Imap4/ImapErrorResponseException.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Runtime.Serialization;

using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4 {
  // Exceptions:
  //   System.Excpetion
  //     System.SystemException
  //       Smdn.Net.Imap4.ImapExcetion
  //         Smdn.Net.Imap4.ImapInvalidOperationException
  //           Smdn.Net.Imap4.ImapErrorResponseException

  [Serializable]
  public class ImapErrorResponseException : ImapInvalidOperationException {
    [NonSerialized]
    private ImapCommandResult result;

    public ImapCommandResult Result {
      get { return result; }
    }

    public ImapErrorResponseException()
      : base()
    {
      this.result = null;
    }

    public ImapErrorResponseException(ImapCommandResult result)
      : this(string.Format("{0}: {1}", result.Code, result.ResultText), result)
    {
    }

    public ImapErrorResponseException(string message, ImapCommandResult result)
      : base(message)
    {
      this.result = result;
    }

    public ImapErrorResponseException(string message, Exception innerException)
      : base(message, innerException)
    {
      this.result = null;
    }

    protected ImapErrorResponseException(SerializationInfo info, StreamingContext context)
      : base(info, context)
    {
      // TODO
      //Result = info.GetValue("Result", typeof(ImapCommandResult));
    }

    /*
    public override void GetObjectData(SerializationInfo info, StreamingContext context)
    {
      base.GetObjectData(info, context);

      // TODO
      //info.AddValue("Result", Result);
    }
    */
  }
}

==> Smdn.Net.Imap4.Client-0.85.tar.bz2: Smdn.Net.Imap4.Client-0.85/Smdn.Net.Imap4.Client/Smdn.Net.Imap4/ImapErrorResponseException.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2013 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using System.Runtime.Serialization;

using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4 {
  // Exceptions:
  //   System.Excpetion
  //     System.SystemException
  //       Smdn.Net.Imap4.ImapExcetion
  //         Smdn.Net.Imap4.ImapInvalidOperationException
  //           Smdn.Net.Imap4.ImapErrorResponseException

  [Serializable]
  public class ImapErrorResponseException : ImapInvalidOperationException {
    private ImapCommandResult result;

    public ImapCommandResult Result {
      get { return result; }
    }

    public ImapErrorResponseException()
      : base()
    {
      this.result = null;
    }

    public ImapErrorResponseException(ImapCommandResult result)
      : this(string.Format("{0}: {1}", result.Code, result.ResultText), result)
    {
    }

    public ImapErrorResponseException(string message, ImapCommandResult result)
      : base(message)
    {
      this.result = result;
    }

    public ImapErrorResponseException(string message, Exception innerException)
      : base(message, innerException)
    {
      this.result = null;
    }

    protected ImapErrorResponseException(SerializationInfo info, StreamingContext context)
      : base(info, context)
    {
      this.result = (ImapCommandResult)info.GetValue("result", typeof(ImapCommandResult));
    }

    public override void GetObjectData(SerializationInfo info, StreamingContext context)
    {
      base.GetObjectData(info, context);

      info.AddValue("result", result);
    }
  }
}
